.. module:: cupyx.optimizing

Automatic Kernel Parameters Optimizations
=========================================

.. autosummary::
   :toctree: generated/
   :nosignatures:

   cupyx.optimizing.optimize
